.. gipc documentation master file
   Copyright 2012-2021 Dr. Jan-Philip Gehrcke. See LICENSE file for details.


########################################
gipc: child processes and IPC for gevent
########################################

gipc (pronunciation as in “gipsy”) is an open-source Python library created by
`Jan-Philip Gehrcke <https://gehrcke.de>`_. It provides reliable child
process management and inter-process communication (IPC) in the context of
`gevent <https://github.com/gevent/gevent>`_.

This documentation applies to gipc |release|. It was built on |today|.


**Quick links:**

- `gipc on GitHub <https://github.com/jgehrcke/gipc>`_
- `gipc on PyPI <https://pypi.python.org/pypi/gipc>`_
- `Changelog <https://github.com/jgehrcke/gipc/blob/master/CHANGELOG.rst>`_
- `gipc on Bitbucket <https://bitbucket.org/jgehrcke/gipc>`_ (legacy)


**Table of contents:**

.. toctree::
    :maxdepth: 2

    overview
    background
    usage
    when
    challenges
    archnotes
    reliable
    winnotes
    examples
    api
    contact


.. Indices and tables
.. ==================
..
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
